@@ -15,3 +15,8 @@ from fileio import providers
 from fileio.utils import settings
 from fileio.core.types import File, FileLike, FileType, FileListType
 
+from fileio.types.etc import ParsedFile, PreparedFile
+
+# from fileio.converters.base import BaseConverter
+# PreparedFile.update_forward_refs()
+# ParsedFile.update_forward_refs()
\ No newline at end of file
